IntoUpstreamSelector

Trait IntoUpstreamSelector 

pub trait IntoUpstreamSelector {
    type UpstreamSelector: UpstreamSelector;

    // Required method
    fn into_upstream(self) -> Self::UpstreamSelector;
}
represents something that can be used as an upstream selector

This primarily exists so &str can be used as a synonym for Url. All UpstreamSelectors also are IntoUpstreamSelector

Required Associated Types

type UpstreamSelector: UpstreamSelector

the type that Self will be transformed into

Required Methods

fn into_upstream(self) -> Self::UpstreamSelector

transform self into the upstream selector

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoUpstreamSelector for &str

Source

impl IntoUpstreamSelector for String

Implementors